@@ -74,13 +74,13 @@ from clu.predicates import (negate,
                             haslength,
                             isiterable, ismergeable,
                             always, never, nuhuh,
-                            no_op, or_none, resolve,
+                            no_op, or_none, stor_none, resolve,
                             getpyattr, getitem,
-                            accessor, collator, searcher,
-                            attr, pyattr, item,
-                            attrs, pyattrs, items,
-                            attr_search, pyattr_search, item_search,
-                            attr_across, pyattr_across, item_across,
+                            accessor, acquirer, collator, searcher,
+                            attr, stattr, pyattr, item,
+                            attrs, stattrs, pyattrs, items,
+                            attr_search, stattr_search, pyattr_search, item_search,
+                            attr_across, stattr_across, pyattr_across, item_across,
                             isenum, enumchoices,
                             isaliasdescriptor, hasmembers, hasaliases,
                             predicate_nop, function_nop, uncallable,
@@ -280,13 +280,13 @@ __all__ = ('Image',
            'haslength',
            'isiterable', 'ismergeable',
            'always', 'never', 'nuhuh',
-           'no_op', 'or_none', 'resolve',
+           'no_op', 'or_none', 'stor_none', 'resolve',
            'getpyattr', 'getitem',
-           'accessor', 'collator', 'searcher',
-           'attr', 'pyattr', 'item',
-           'attrs', 'pyattrs', 'items',
-           'attr_search', 'pyattr_search', 'item_search',
-           'attr_across', 'pyattr_across', 'item_across',
+           'accessor', 'acquirer', 'collator', 'searcher',
+           'attr', 'stattr', 'pyattr', 'item',
+           'attrs', 'stattrs', 'pyattrs', 'items',
+           'attr_search', 'stattr_search', 'pyattr_search', 'item_search',
+           'attr_across', 'stattr_across', 'pyattr_across', 'item_across',
            'isenum', 'enumchoices',
            'isaliasdescriptor', 'hasmembers', 'hasaliases',
            'predicate_nop', 'function_nop', 'uncallable',
