@@ -4,7 +4,7 @@ from __future__ import print_function
 import pytest
 
 # Currently these need to be defined at the module level,
-# in order for “thingname_search(…)” to find them properly –
+# in order for “search_for_name(…)” to find them properly –
 # q.v. “test_exporter_export_lambdas_no_name_provided(…)”
 # definition sub.:
 yo_dogg_lambda = lambda: print("Yo dogg.")
@@ -14,8 +14,44 @@ class TestExporting(object):
     
     """ Run the tests for the clu.exporting module. """
     
+    def test_exporterbase_subclass(self, dirname):
+        from clu.exporting import ExporterBase, Registry
+        import os
+        
+        prefix = dirname.subdirectory('yodogg')
+        yodogg = prefix.subdirectory('yodogg')
+        assert prefix.exists
+        assert yodogg.exists
+        
+        # Subclass ExporterBase locally -
+        # This will register the subclass:
+        class Exporter(ExporterBase, prefix=prefix, appname="yolocal"):
+            pass
+        
+        # Instantiate the ExporterBase subclass –
+        # This will register the instance:
+        exporter = Exporter(path=yodogg.subpath('iheard.py'))
+        export = exporter.decorator()
+        
+        @export
+        def youlike():
+            return "registries"
+        
+        assert os.path.exists(exporter.path)
+        assert exporter.dotpath == 'yodogg.iheard'
+        assert 'clu' in Registry.all_appnames()
+        assert 'yolocal' in Registry.all_appnames()
+        assert len(Exporter.modulenames()) == 1
+        assert len(exporter) == 1
+        assert exporter['youlike'] is youlike
+        assert Exporter['yodogg.iheard'] is exporter
+        assert Registry['yolocal'] is Exporter
+        
+        assert Registry['yolocal']['yodogg.iheard']['youlike']() == "registries"
+    
     @pytest.mark.filterwarnings("ignore::DeprecationWarning")
     def test_exporter_instance_registry(self, clumods):
+        from clu.constants.consts import BASEPATH
         from clu.constants.data import MODNAMES
         from clu.exporting import path_to_dotpath, Exporter
         
@@ -28,7 +64,8 @@ class TestExporting(object):
             module = clumods[modname]
             assert Exporter[modname]
             assert Exporter[modname].path == module.__file__
-            assert Exporter[modname].dotpath == path_to_dotpath(module.__file__)
+            assert Exporter[modname].dotpath == path_to_dotpath(module.__file__,
+                                                                relative_to=BASEPATH)
             assert Exporter[modname].all_tuple() == module.__all__
     
     def test_combine_real_world_exporters_2(self):
@@ -148,7 +185,7 @@ class TestExporting(object):
     
     @pytest.mark.TODO
     def test_exporter_export_lambdas_no_name_provided(self):
-        # N.B. “thingname_search()” should inspect locals (?!)
+        # N.B. “search_for_name()” should inspect locals (?!)
         # in order to make this work at non-module-level:
         from clu.exporting import Exporter
         from clu.naming import nameof
